darkhistory.spec.transferfunclist.TransferFuncListArray — DarkHistory documentation

# darkhistory.spec.transferfunclist.TransferFuncListArray

class `darkhistory.spec.transferfunclist.` `TransferFuncListArray`(tflist_arr, x_arr)

  Array of TransferFuncList for array of xH, xHe values.

  Parameters: | tflist_arr : list of TransferFuncList TransferFuncList objects to add to the array. If 2D, should be indexed by (xH, xHe). x_arr : ndarray Array of xH or (xH, xHe) values corresponding to tflist_arr.
  Attributes: | rs : ndarray Redshift abscissa of the transfer functions. in_eng : ndarray Injection energy abscissa of the transfer functions. eng : ndarray Energy abscissa of the transfer functions. dlnz : float The d ln(1+z) step for the transfer functions. spec_type : {‘N’, ‘dNdE’} The type of spectra stored in the transfer functions.

  `__init__`(tflist_arr, x_arr)

    Initialize self. See help(type(self)) for accurate signature.

  Methods

  `__init__`(tflist_arr, x_arr) | Initialize self.

#### Previous topic

darkhistory.spec.transferfunclist.TransferFuncList

#### Next topic

darkhistory.spec.transferfunction

### This Page

Show Source